=========================
Formatting and Conversion
=========================

Notebooks are rich interactive documents that combine live code, narrative text
(using markdown), visualizations, and other rich media. The following utility
subprojects allow programmatic format conversion and manipulation of notebook
documents.

.. glossary::

    `nbconvert <https://nbconvert.readthedocs.io/en/latest/>`__
        Convert dynamic notebooks to static formats such as HTML, Markdown,
        LaTeX/PDF, and reStructuredText.
        `Documentation <https://nbconvert.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/nbconvert>`__

    `nbformat <https://nbformat.readthedocs.io/en/latest/>`__
        Work with notebook documents programmatically.
        `Documentation <https://nbformat.readthedocs.io/en/latest/>`__ |
        `Repo <https://github.com/jupyter/nbformat>`__
